====================
 Experipy Changelog
====================


Version 0.2.0
-------------

- Various bugfixes
- Added support for configuration of namespaces via an ``~/.experipyrc`` file
  using ConfigParser.
- Added :func:`~Namespace.dump_full_config` helper for generating the config
  file.

Version 0.1.0
-------------

First public release.
